# customer_analyzer_cu

## Описание

Это Python-пакет, который помогает анализировать данные о клиентах и генерировать подробный отчет о распределении клиентов по возрастным группам и городам.

## Установка и использование

```bash
pip install customer_analyzer_cu